The data files test_dc2_training_9816.hdf5 and test_dc2_validation_9816.hdf5 are made with the simple notebook make_rail_sample_data.ipynb.  This simply grabs a subset of cosmoDC2v1.1.4 galaxies from healpix 9816 that have had 10-year mock errors added to them and selects small subsamples for testing.  As this is only one healpix pixel, it is subject to sample variance. For a more comprehensive test set we should include several spatially separated healpix pixels so that LSS does not dominate. However, the files are suitable for testing purposes.
